@@ -1,5 +1,5 @@
 package JSONAPI::Document;
-$JSONAPI::Document::VERSION = '0.9';
+$JSONAPI::Document::VERSION = '1.0';
 # ABSTRACT: Turn DBIx results into JSON API documents.
 
 use Moo;
@@ -120,7 +120,7 @@ sub resource_document {
         }
     }
 
-    my $resource_type = $self->chi->compute($noun->plural, undef, sub {
+    my $resource_type = $self->chi->compute(__PACKAGE__ . ':' . $noun->plural, undef, sub {
         my @words = $self->segmenter->segment($noun->plural);
         unless ( @words > 0 ) {
             @words = ($noun->plural);
@@ -244,7 +244,7 @@ JSONAPI::Document - Turn DBIx results into JSON API documents.
 
 =head1 VERSION
 
-version 0.9
+version 1.0
 
 =head1 SYNOPSIS
 
